@@ -144,8 +144,9 @@ normalize.initprobs.glm <- function(initprobs, glm.obj) {
 #' probabilities or use Monte Carlo frequencies. Applies only to MCMC sampling.
 #' @param force.heredity Logical variable to force all levels of a factor to be
 #' included together and to include higher order interactions only if lower
-#' order terms are included.  Currently only supported with `method='MCMC'`.
-#' Default is TRUE.
+#' order terms are included.  Currently only supported with `method='MCMC'`
+#' and `method='BAS'` (experimental) on non-Solaris platforms.
+#' Default is FALSE.
 #' @param bigmem Logical variable to indicate that there is access to
 #' large amounts of memory (physical or virtual) for enumeration
 #' with large model spaces, e.g. > 2^25.
@@ -177,11 +178,11 @@ normalize.initprobs.glm <- function(initprobs, glm.obj) {
 #' Li
 #' @references Li, Y. and Clyde, M. (2019) Mixtures of g-priors in Generalized
 #' Linear Models. Journal of the American Statistical Association. 113:1828-1845 \cr
-#' \url{https://doi.org/10.1080/01621459.2018.1469992} \cr
+#' \url{https://dx.doi.org/10.1080/01621459.2018.1469992} \cr
 #' Clyde, M. Ghosh, J. and Littman, M. (2010) Bayesian Adaptive Sampling for
 #' Variable Selection and Model Averaging. Journal of Computational Graphics
 #' and Statistics.  20:80-101 \cr
-#' \url{http://dx.doi.org/10.1198/jcgs.2010.09049} \cr
+#' \url{https://dx.doi.org/10.1198/jcgs.2010.09049} \cr
 #' Raftery, A.E, Madigan, D. and Hoeting, J.A. (1997) Bayesian Model Averaging
 #' for Linear Regression Models. Journal of the American Statistical
 #' Association.
@@ -241,7 +242,7 @@ bas.glm <- function(formula, family = binomial(link = "logit"),
                     prob.rw = 0.5,
                     MCMC.iterations = NULL,
                     control = glm.control(), laplace = FALSE, renormalize = FALSE,
-                    force.heredity = TRUE,
+                    force.heredity = FALSE,
                     bigmem = FALSE) {
   num.updates <- 10
   call <- match.call()
@@ -348,7 +349,7 @@ bas.glm <- function(formula, family = binomial(link = "logit"),
   }
 
   parents <- matrix(1, 1, 1)
-  if (method == "deterministic" | method == "MCMC+BAS") force.heredity <- FALSE # not working yet
+  if (method == "deterministic" | method == "MCMC+BAS" | is.solaris()) force.heredity <- FALSE # not working yet
   if (force.heredity) {
     parents <- make.parents.of.interactions(mf, data)
 
