@@ -66,19 +66,21 @@ Copyright 1984, 1987, 1988, 2000 by Stephen L. Moshier
 */
 
 #include "mconf.h"
+#include <Rmath.h>
 
 #ifdef ANSIPROT
 extern double exp ( double );
 extern double log ( double );
-extern double gamma ( double );
-extern double lgam ( double );
 extern double fabs ( double );
+double gam(double), lgam(double);
 double hyp2f0 ( double, double, double, int, double * );
 static double hy1f1p(double, double, double, double *);
 static double hy1f1a(double, double, double, double *);
 double hyperg (double, double, double);
 #else
-double exp(), log(), gamma(), lgam(), fabs(), hyp2f0();
+double exp(), log(), gammafn(), lgammafn(),fabs(), 
+double hyp2f0();
+double gam(), lgam();
 static double hy1f1p();
 static double hy1f1a();
 double hyperg();
@@ -243,14 +245,14 @@ if( b > 0 )
 
 h1 = hyp2f0( a, a-b+1, -1.0/x, 1, &err1 );
 
-temp = exp(u) / gamma(b-a);
+temp = exp(u) / gam(b-a);
 h1 *= temp;
 err1 *= temp;
 
 h2 = hyp2f0( b-a, 1.0-a, 1.0/x, 2, &err2 );
 
 if( a < 0 )
-	temp = exp(t) / gamma(a);
+	temp = exp(t) / gam(a);
 else
 	temp = exp( t - lgam(a) );
 
@@ -267,7 +269,7 @@ acanc = fabs(err1) + fabs(err2);
 
 if( b < 0 )
 	{
-	temp = gamma(b);
+	temp = gam(b);
 	asum *= temp;
 	acanc *= fabs(temp);
 	}
