@@ -51,6 +51,7 @@ double FitModel(SEXP Rcoef_m, SEXP Rse_m, double *XtY, double *XtX, int *model_m
 	}
 	*pmse_m = yty;
 	 memcpy(coefficients, XtYwork, sizeof(double)*pmodel);
+
 	if (pivot == 1) {
   	*rank_m = cholregpivot(XtYwork, XtXwork, coefficients, se_m, pmse_m, pmodel, nobs, pivot, tol);
 	}
@@ -250,11 +251,11 @@ double random_switch_heredity(int *model, struct Var *vars, int n,
 
 
 // [[register]]
-extern SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim, SEXP incint,
-                     SEXP Ralpha,SEXP method,SEXP modelprior, SEXP Rupdate,
-                     SEXP Rbestmodel, SEXP plocal, SEXP BURNIN_Iterations,
-                     SEXP MCMC_Iterations, SEXP LAMBDA, SEXP DELTA,
-                     SEXP Rthin, SEXP Rparents, SEXP Rpivot, SEXP Rtol)
+SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeldim,
+              SEXP incint, SEXP Ralpha, SEXP method, SEXP modelprior, SEXP Rupdate,
+              SEXP Rbestmodel, SEXP plocal, SEXP BURNIN_Iterations,
+              SEXP MCMC_Iterations, SEXP LAMBDA, SEXP DELTA,
+              SEXP Rthin, SEXP Rparents, SEXP Rpivot, SEXP Rtol)
 {
 	int nProtected = 0;
 	SEXP RXwork = PROTECT(duplicate(X)); nProtected++;
@@ -317,10 +318,13 @@ extern SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeld
 	n = sortvars(vars, probs, p);
 	for (i =n; i <p; i++) REAL(MCMCprobs)[vars[i].index] = probs[vars[i].index];
 	for (i =0; i <n; i++) REAL(MCMCprobs)[vars[i].index] = 0.0;
+	int noInclusionIs1 = no_prior_inclusion_is_1(p, probs);
 
 
-	// fill in the sure things
+	//  allocate working model and fill in the sure things
 	int *model = ivecalloc(p);
+	memset(model, 0, p * sizeof(int));
+
 	for (i = n, n_sure = 0; i < p; i++)  {
 		model[vars[i].index] = (int) vars[i].prob;
 		if (model[vars[i].index] == 1) ++n_sure;
@@ -359,7 +363,7 @@ extern SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeld
                &shrinkage_m);
 
 
-	prior_m  = compute_prior_probs(model,pmodel,p, modelprior);
+	prior_m  = compute_prior_probs(model,pmodel,p, modelprior, noInclusionIs1);
 	if (prior_m == 0.0)  Rprintf("warning initial model has 0 prior probabilty\n");
 	SetModel2(logmargy, shrinkage_m, prior_m, sampleprobs, logmarg, shrinkage, priorprobs, m);
 	SetModel(Rcoef_m, Rse_m, Rmodel_m, mse_m, R2_m,	beta, se, modelspace, mse, R2, m);
@@ -405,7 +409,7 @@ extern SEXP mcmc_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit, SEXP Rmodeld
 		}
 
 		if (newmodel == 1) {
-		  prior_m = compute_prior_probs(model,pmodel,p, modelprior);
+		  prior_m = compute_prior_probs(model,pmodel,p, modelprior, noInclusionIs1);
 		  if (prior_m == 0.0) {
 		    MH *= 0.0;
 		  }
